BOOST_PP_IS_ITERATING

The BOOST_PP_IS_ITERATING macro is defined when a file-iteration is in progress.

#### Usage

#if !defined(BOOST_PP_IS_ITERATING) // ...

#### Remarks

If a file-iteration is in progress, this macro is defined as 1. This means that the following will also work:
#if !BOOST_PP_IS_ITERATING // ...
This macro is defined to guard a file from infinite inclusion.

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)